@@ -27,6 +27,8 @@ logger = logging.getLogger(__name__)
 import os
 
 
+class SafetyError(Exception):
+    pass
 
 
 class BaseBergen:
@@ -38,6 +40,7 @@ class BaseBergen:
             client_type: ClientType = ClientType.CLIENT,
             log_stream=False,
             auto_connect=False,
+            capture_exceptions=False,
             **kwargs) -> None:
         
         
@@ -55,7 +58,7 @@ class BaseBergen:
 
         self.config = config
         self.client_type = client_type
-
+        self.capture_exceptions=False
 
         self.registered_hooks = Hooks()
 
@@ -257,10 +260,9 @@ class BaseBergen:
         if self._provider: await self._provider.disconnect()
         if self._entertainer: await self._entertainer.disconnect()
 
-        wards = self.identifierWardMap.values()
-        for ward in wards:
-            await ward.disconnect()
-
+        ward_registry = get_ward_registry()
+        await asyncio.gather(*[ward.disconnect() for ward in ward_registry.wards])
+        print("Sucessfulyl disconnected")
 
     def negotiate(self):
         assert not self.loop.is_running(), "You cannot negotiate with an already running Event loop, please ue negotiate_async"
@@ -307,8 +309,15 @@ class BaseBergen:
         return self
 
 
-    async def __aexit__(self,*args, **kwargs):
-        await self.disconnect_async()
+    async def __aexit__(self, type, value, traceback):
+        try:
+            if value and isinstance(value, asyncio.CancelledError): 
+                raise SafetyError("We caputered a Cancellation at the Bergen Context Level. Please make sure to capture it before in your code. See documentation!") from value#
+        
+
+        except Exception as e:    
+            await self.disconnect_async()
+            if not self.capture_exceptions: raise e
 
 
     def disconnect(self):
