@@ -337,10 +337,7 @@ class Reservation:
 
     
     def assign(self, *args, bypass_shrink=False, bypass_expand=False, persist=True, **kwargs):
-        if False:
-            return self.loop.run_until_complete(self.assign_async(*args, bypass_shrink=bypass_shrink, bypass_expand=bypass_expand, persist=persist, **kwargs))
-        else:
-            return self.assign_async(*args, bypass_shrink=bypass_shrink, bypass_expand=bypass_expand, persist=persist, **kwargs)
+        return self.assign_async(*args, bypass_shrink=bypass_shrink, bypass_expand=bypass_expand, persist=persist, **kwargs)
 
     def __enter__(self):
         self.in_sync = True
