@@ -102,8 +102,9 @@ class ArnheimAsyncModelManager(BaseManager, Generic[ModelType]):
         return await self._call_meta("filter", ward=ward, **kwargs)
 
 
-    async def fetch(self, typed_gql, ward=None, **kwargs) -> List[ModelType]:
+    async def fetch(self, gql, ward=None, **kwargs) -> List[ModelType]:
         from bergen.types.utils import parse_kwargs
+        typed_gql = DelayedGQL(gql)(self.model)
         return await typed_gql.run(ward=ward, variables=parse_kwargs(kwargs))
 
 
